==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 外掛程式不相容此系統。</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設定</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設定</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>正在連線...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>藍牙關閉</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>新增鍵盤配置</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>日期時間</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 小時制</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 小時制</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設定</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>啟用網路</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>停用網路</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>確定清空 %1 個項目？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>此動作無法復原</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>未知裝置</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>未知磁碟區</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁碟</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>全部卸載</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>啟動器</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>退出安全模式</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>任務欄安全模式</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>任務欄已進入安全模式，退出安全模式後即可正常顯示</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>頂部</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左側</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右側</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>永遠顯示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>永遠隱藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智慧隱藏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>附加元件</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任務檢視</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>解除駐停</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>關閉有線網路</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>啟用有線網路</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>關閉無線網路</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>啟用有線網路</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>停用網路</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>啟用網路</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>已停用裝置</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>無線連接：%1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>有線網路：%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連線</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連線但不能存取網路</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>已拔除網路線</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連線失敗</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有線網路 %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>螢幕鍵盤</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設定</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>電量 %1，剩餘 %2 分鐘</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>電量 %1，剩餘 %2 小時 %3 分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>正在充電 %1，距離完成尚餘 %2 分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>正在充電 %1，距離完成尚餘 %2 小時 %3 分鐘</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>充電完成</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>電量 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 正在充電</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>電量%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>電量%1，已充滿</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>顯示桌面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>解除駐停</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>切換帳戶</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設定</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>裝置</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>取消靜音</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>音效設定</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>回收桶</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>回收桶－%1 個檔案</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>回收桶－%1 個檔案</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>系統匣</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>無線網路 %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.orig.tar.xz: dde-dock-5.5.38/translations/dde-dock_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 外掛程式不相容此系統。</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飛航模式</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>飛航模式開啟</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>飛航模式設定</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>飛航模式關閉</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飛航模式</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設定</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設定</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>正在連線...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>藍牙關閉</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>新增鍵盤配置</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>日期時間</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 小時制</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 小時制</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設定</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>確定清空 %1 個項目？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>此動作無法復原</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>未知裝置</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>未知磁碟區</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁碟</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>全部卸載</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>啟動器</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>退出安全模式</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>任務欄安全模式</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>任務欄已進入安全模式，退出安全模式後即可正常顯示</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>頂部</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左側</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右側</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>永遠顯示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>永遠隱藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智慧隱藏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>任務欄設定</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>多屏顯示設定</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>外掛程式區域</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>選擇顯示在任務欄外掛程式區域的圖示</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>時尚模式</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>頂部</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左側</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右側</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>永遠顯示</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>永遠隱藏</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>智慧隱藏</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>狀態</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>任務欄位置</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>跟隨滑鼠位置顯示</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>僅主屏顯示</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任務檢視</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>解除駐停</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>螢幕鍵盤</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設定</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>電量 %1，剩餘 %2 分鐘</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>電量 %1，剩餘 %2 小時 %3 分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>正在充電 %1，距離完成尚餘 %2 分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>正在充電 %1，距離完成尚餘 %2 小時 %3 分鐘</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>電量 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 正在充電</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>電量%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>電量%1，已充滿</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>任務欄</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>顯示桌面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>解除駐停</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>切換帳戶</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設定</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>裝置</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>取消靜音</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>音效設定</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>回收桶</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>回收桶－%1 個檔案</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>回收桶－%1 個檔案</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>移動到回收站</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
</TS>
